@@ -1,6 +1,6 @@
 package Sim::OPT::Descend;
 # This is the module Sim::OPT::Descend of Sim::OPT, a program for detailed metadesign managing parametric explorations, distributed under a dual licence, open-source (GPL v3) and proprietary.
-# Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is proprietary. The open-source, GPL version of it can be found at https://metacpan.org/dist/Sim-OPT.
+# Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is GPL. By consequence, this is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
 use Math::Trig;
 use Math::Round;
@@ -58,6 +58,29 @@ sub even
     return odd ($number - 1);
 }
 
+
+sub auto_objcol {
+  my ($arr_r) = @_;
+  my $c = 0;
+
+  foreach my $line ( @$arr_r ) 
+  {
+    chomp $line;
+    my @f = split(/,/, $line, -1);  # -1 keeps empties (safe with ,,)
+
+    for my $i (0 .. $#f) 
+    {
+      my $v = $f[$i];
+      if (defined $v && $v =~ /^\s*[-+]?\d*\.?\d+(?:[eE][-+]?\d+)?\s*$/) 
+      {
+        $c = $i;  # last numeric on the line
+      }
+    }
+  }
+  return $c;
+}
+
+
 sub auto_objcol_file 
 {
   my ( $file ) = @_;
@@ -85,32 +108,6 @@ sub auto_objcol_file
 }
 
 
-sub auto_objcol 
-{
-  my @arr = @{ $_[0] };
-  
-  foreach my $line ( @arr )
-  {
-    unless ( defined( $line ) )
-    {
-      return( 0 ); 
-    }
-    chomp $line;
-    my @f = split( /,/, $line );
-
-    my $c = 0;
-    for my $i (0 .. $#f) {
-      my $v = $f[$i];
-      # numeric? (integer/float/scientific)
-      if ( defined ( $v ) and ( $v =~ /^\s*[-+]?\d*\.?\d+(?:[eE][-+]?\d+)?\s*$/ ) )
-      {
-        $c = $i;
-      }
-    } #say $tee "!!! OBJECTIVECOLUMN: $c";
-  }
-  return( $c );
-}
-
 
 sub descend
 {
@@ -203,6 +200,27 @@ sub descend
 
   my $from     = $instances[0]{origin} // $instances[0]{from}; 
 
+  if ( !$dirfiles{repfile} )
+  {
+    $dirfiles{repfile} = "$mypath/$file-report-$countcase-$countblock.csv";
+  }
+  
+  if ( !$dirfiles{sortmixed} )
+  {
+    $dirfiles{sortmixed} = "$dirfiles{repfile}" . "_sortm.csv";
+  }
+  
+  
+  if ( !$dirfiles{totres} )
+  {
+    $dirfiles{totres} = "$mypath/$file-$countcase" . "_totres.csv";
+  }
+  
+  if ( !$dirfiles{ordres} )
+  {
+    $dirfiles{ordres} = "$mypath/$file-$countcase" . "_ordres.csv";
+  }
+
   #say $tee "RELAUNCHED IN DESCEND WITH INST " . dump( %inst );
 
   my ( $direction, $starorder );
@@ -272,11 +290,12 @@ sub descend
 
   my $confinterlinear = "$mypath/" . $dowhat{confinterlinear} ;
 
+  
   my $repfile = $dirfiles{repfile}; say $tee "IN DESCENT FROM DIRFILES, \$countblock $countblock, \$repfile $repfile";
 
   if ( $fire eq "y" )
   {
-    $repfile = $dirfiles{repfile} . "-fire-$stamp.csv";###DDD!!!
+    $repfile = $repfile . "-fire-$stamp.csv";###DDD!!!
   }
 
   if ( not( $repfile ) )
@@ -289,16 +308,17 @@ sub descend
   {
     Sim::OPT::washduplicates( $repfile );
   }
+  
 
   my $sortmixed = $dirfiles{sortmixed};
 
+  if ( !$sortmixed ){ die; };
+
   if ( $fire eq "y" )
   {
-    $sortmixed = $dirfiles{sortmixed} . "-fire-$stamp.csv";###DDD!!!
+    $sortmixed = $sortmixed . "-fire-$stamp.csv";###DDD!!!
   }
 
-  if ( not( $sortmixed ) ){ die; }
-
   my ( $entryfile, $exitfile, $orderedfile );
   my $entryname = $dirfiles{entryname};
   if ( $entryname ne "" )
@@ -340,7 +360,8 @@ sub descend
   #}
 
   #say $tee "!!!!IN DESCEND \$repfile " . dump($repfile);
-  if ( not( -e $repfile ) ){ die "There isn't \$repfile: $repfile"; };
+  if ( ( $dowhat{dumpfiles} eq "y" ) and ( not( -e $repfile ) ) )
+  { die "There isn't \$repfile: $repfile"; };
 
 
   my $instance = $instances[0]; #
@@ -708,7 +729,7 @@ sub descend
 
   if ( $objectivecolumn eq "" )
   {
-    $dowhat{objectivecolumn} = auto_objcol( \@packet );
+    $dowhat{objectivecolumn} = auto_objcol( \@packet ); say $tee "IN DESCENT CALCULATED \$dowhat{objectivecolumn} $dowhat{objectivecolumn}"; 
     $objectivecolumn = $dowhat{objectivecolumn};
   }
 
@@ -722,7 +743,7 @@ sub descend
   #if ( not( -e $weighttwo ) ){ die; };
 
 
-  if ( not( ( $repfile ) and ( -e $repfile ) ) )
+  if ( ( $dowhat{dumpfiles} eq "y" ) and ( not ( ( $repfile ) and ( -e $repfile ) ) ) )
   {
     die( "$!" );
   }
@@ -735,7 +756,7 @@ sub descend
     my %inst = %{ $inst_r }; say $tee "IN SORTMIXED \%inst" . dump( \%inst );
     my %dirfiles = %{ $dirfiles_r };
     my %vehicles = %{ $vehicles_r };
-    my @packet = @$packet_r;
+    my @packet = @$packet_r; say $tee "IN SORTMIXED RECEIVED \@packet: " . dump( @packet );
 
 
     #my $weighttwoNEW = $weighttwo . "-NEW.csv"; ###HERE!!!### SWITCH
@@ -769,7 +790,7 @@ sub descend
 
       #@lines = uniq( @lines );
       @lines = uniq( @packet );
-      say $tee "\$objectivecolumn: $objectivecolumn, FIRSTLINE! " . dump( $lines[0] ) . "OF \$weighttwo: $weighttwo";
+      #say $tee "\$objectivecolumn: $objectivecolumn, FIRSTLINE! " . dump( $lines[0] ) . "OF \$weighttwo: $weighttwo";
 
       my @splitteds;
       foreach my $line ( @lines )
@@ -779,8 +800,8 @@ sub descend
         $line =~ s/,?// ;
         $line =~ s/ $// ;
         $line =~ s/,?// ;
-        #my @elts = split( "," , $line );
-        #push( @splitteds, [ @elts ] );
+        my @elts = split( "," , $line );
+        push( @splitteds, [ @elts ] );
       }
 
       say $tee "\$direction $direction, \$starorder $starorder, \$objectivecolumn: $objectivecolumn, LINES! " . dump( @lines );
@@ -2142,7 +2163,7 @@ Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is proprietary. The open-source, GPL version of it can be found at https://metacpan.org/dist/Sim-OPT.
+Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is GPL. By consequence, this is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
 
 =cut
