@@ -1,6 +1,6 @@
 package Sim::OPT::Report;
 # This is the module Sim::OPT::Retrieve of Sim::OPT, a program for detailed metadesign managing parametric explorations, distributed under a dual licence, open-source (GPL v3) and proprietary.
-# Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is proprietary. The open-source, GPL version of it can be found at https://metacpan.org/dist/Sim-OPT.
+# Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is GPL. By consequence, this is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
 
 # use v5.20;
@@ -1067,12 +1067,17 @@ sub newreport # This function retrieves the results of interest from the texts f
   my $is = $d{is};
   my $double;
 
+  if ( !$dirfiles{repfile} )
+  {
+    $dirfiles{repfile} = "$mypath/$file-report-$countcase-$countblock.csv";
+  }
   my $repfile = $dirfiles{repfile}; say $tee "IN REPORT FROM DIRFILES \$repfile $repfile";
 
+
   if ( $fire eq "y" )
   {
     $double = $repfile;
-    $repfile = $dirfiles{repfile} . "-fire-$stamp.csv";
+    $repfile = $repfile . "-fire-$stamp.csv";
   }
 
   my $origin = $d{origin};
@@ -1595,7 +1600,12 @@ sub newreport # This function retrieves the results of interest from the texts f
     `rm -f $mypath/*.grt` ;
     #print $tee "rm -f $mypath/*.grt";
   }
-  if (not( -e $repfile ) ){ die; };
+
+  if ( ( $dowhat{dumpfiles} eq "y" ) and (not( -e $repfile ) ) )
+  {
+    die;
+  }
+  
 
   if ( $dirfiles{launching} eq "y" )
   {
@@ -1699,7 +1709,7 @@ Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is proprietary. The open-source, GPL version of it can be found at https://metacpan.org/dist/Sim-OPT.
+Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is GPL. By consequence, this is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
 
 =cut
