@@ -1,6 +1,6 @@
 package Sim::OPT::Sim;
 # This is the module Sim::OPT::Sim of Sim::OPT, distributed under a dual licence, open-source (GPL v3) and proprietary.
-# Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is proprietary. The open-source, GPL version of it can be found at https://metacpan.org/dist/Sim-OPT.
+# Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is GPL. By consequence, this is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
 
 use Exporter;
@@ -98,8 +98,11 @@ sub sim
   my %inst = %{ $dat{inst} };
   my @precedents = @{ $dat{precedents} };
   my $postproc = $dat{postproc};
+  my $pierce = $dat{pierce};
+  my $last = $dat{last};
+  my @bomb = @{ $dat{bomb} };
   my $winningvalue;
-  my @pocket;
+  my ( @pocket );
 
   #my $retlist = $dirfiles{retlist};####!!!
   #my $retblock = $dirfiles{retblock};
@@ -129,6 +132,8 @@ sub sim
   my $from = $d{from};
   my @blockelts = @{ $d{blockelts} }; #say $tee "HERE IN SIM \@blockelts: " . dump( @blockelts );
   my %varnums = %{ $d{varnums} };
+  my $repfile;
+
 
   #if ( $countcase > $#sweeps )# NUMBER OF CASES OF THE CURRENT PROBLEM
   #{
@@ -185,11 +190,15 @@ sub sim
     my $fire = $dt{fire};
     my $gaproc = $dt{gaproc};
 
-    my $repfile = $dirfiles{repfile}; say $tee "IN SIM FROM DIRFILES, \$countblock $countblock, \$repfile $repfile";
+    if ( !$dirfiles{repfile} )
+    {
+      $dirfiles{repfile} = "$mypath/$file-report-$countcase-$countblock.csv";
+    }
+    $repfile = $dirfiles{repfile}; say $tee "IN SIM FROM DIRFILES, \$countblock $countblock, \$repfile $repfile";
 
     if ( ( $fire eq "y" ) and ( $precious ne "" ) )
     {
-      $repfile = $dirfiles{repfile} . "-fire-$is.csv";###DDD!!!
+      $repfile = $repfile . "-fire-$is.csv";###DDD!!!
     }
 
     my $skip = $dowhat{$countvar}{skip}; #########################################
@@ -588,10 +597,11 @@ XXX
         %dirfiles = %$dirfiles_r;
       }
     }
-
+    
+    my $dirfiles_r;
     if ( $dowhat{newreport} eq "y" )
     {
-      ( my $dirfiles_r, $instant ) = Sim::OPT::Report::newreport(
+      ( $dirfiles_r, $instant ) = Sim::OPT::Report::newreport(
       {
         instance => $instance, dirfiles => \%dirfiles,
         resfile => $resfile, flfile => $flfile,
@@ -621,298 +631,348 @@ XXX
   #close SIMLIST;
   #close SIMBLOCK;
   
-  my @newbowl;  my $expected_r = Sim::OPT::enumerate( \%varnums, \@blockelts, $from ); #say $tee "IN POSTSIM \$countblock $countblock \$expected_r " . dump( $expected_r );
-  #say $tee "IN POSTSIM  \$from $from  \$expected_r  " . dump( $expected_r ) . " \%varnums " . dump( \%varnums ) . "\@blockelts " . dump( @blockelts );
- 
-  my %present;
-  
-  @{ $dirfiles{repsblocks}{$countcase}{$countblock} } = uniq( @{ $dirfiles{repsblocks}{$countcase}{$countblock} } );
-  #say $tee "IN DESCEND \@{ \$dirfiles{repsblocks}{\$countcase}{\$countblock} }: " . dump( @{ $dirfiles{repsblocks}{$countcase}{$countblock} } );
- 
-  foreach my $ln ( @{ $dirfiles{repsblocks}{$countcase}{$countblock} } )
-  {
-    chomp $ln;
-    next if $ln =~ /^\s*$/;
 
-    my $rid = Sim::OPT::instid( $ln, $file ); #say $tee "IN POSTSIM \$file $file \$ln $ln \$countblock $countblock \$rid " . dump( $rid );# NOT $repfile
-    if ( defined($rid) and $rid ne "" )
+
+  ########################################################################################################################
+
+  my @newbowl; 
+  my $expected_r;
+
+  unless ( $pierce eq "y" )
+  {
+    $expected_r = Sim::OPT::enumerate( \%varnums, \@blockelts, $from ); say $tee "IN POSTSIM \@blockelts " . dump( @blockelts ) . " \$expected_r " . dump( $expected_r );
+    #say $tee "IN POSTSIM  \$from $from  \$expected_r  " . dump( $expected_r ) . " \%varnums " . dump( \%varnums ) . "\@blockelts " . dump( @blockelts );
+
+
+### @pocket = uniiq( @pocket );
+    @{ $dirfiles{repsblocks}{$countcase}{$countblock} } = uniq( @{ $dirfiles{repsblocks}{$countcase}{$countblock} } );
+    #say $tee "IN DESCEND \@{ \$dirfiles{repsblocks}{\$countcase}{\$countblock} }: " . dump( @{ $dirfiles{repsblocks}{$countcase}{$countblock} } );
+  
+### foreach my $ln ( @pocket )
+    foreach my $ln ( @{ $dirfiles{repsblocks}{$countcase}{$countblock} } )
     {
-      push( @newbowl , $ln );
-      #$dirfiles{reps}{$rid} = $ln; say $tee "IN POSTSIM WRITING \$dirfiles{reps}{\$rid} \$dirfiles{reps}{$rid} " . dump( $dirfiles{reps}{$rid} );# NOT $repfile
-      $present{$rid} = 1; #say $tee "IN POSTSIM \$countblock $countblock \$present{\$rid} \$present{$rid} " . dump( $present{$rid} );# NOT $repfile
-      #say $tee "IN POSTSIM CHECKING: \$rid $rid \$dirfiles{reps}{\$rid}: " . dump( $dirfiles{reps}{$rid} );
+      chomp $ln;
+      next if $ln =~ /^\s*$/;
+
+      my $rid = Sim::OPT::instid( $ln, $file ); #say $tee "IN POSTSIM \$file $file \$ln $ln \$countblock $countblock \$rid " . dump( $rid );# NOT $repfile
+      if ( defined($rid) and $rid ne "" )
+      {
+        push( @newbowl , $ln );
+        #$dirfiles{reps}{$rid} = $ln; say $tee "IN POSTSIM WRITING \$dirfiles{reps}{\$rid} \$dirfiles{reps}{$rid} " . dump( $dirfiles{reps}{$rid} );# NOT $repfile
+        $present{$rid} = 1; #say $tee "IN POSTSIM \$countblock $countblock \$present{\$rid} \$present{$rid} " . dump( $present{$rid} );# NOT $repfile
+        #say $tee "IN POSTSIM CHECKING: \$rid $rid \$dirfiles{reps}{\$rid}: " . dump( $dirfiles{reps}{$rid} );
+      }
+    }
+    
+
+    my %present;
+    foreach my $rid ( @{ $expected_r } )
+    {
+      next if $present{$rid};
+
+      if ( exists $dirfiles{reps}{$rid} )
+      {
+        push( @newbowl, $dirfiles{reps}{$rid} );
+        say $tee "IN POSTSIM EXISTS \$countblock $countblock \$dirfiles{reps}{\$rid} \$dirfiles{reps}{$rid} " . dump( $dirfiles{reps}{$rid} );# NOT $repfile
+      }
     }
   }
   
-  foreach my $rid ( @{ $expected_r } )
+  
+  if ( ( $pierce eq "y" ) and ( $last ) )
   {
-    next if $present{$rid};
+    push ( @bomb, $instant );
+  }
 
-    if ( exists $dirfiles{reps}{$rid} )
+
+  my @newgo;
+
+
+  if ( not ( $pierce eq "y" ) )
+  {
+    @newgo = @newbowl; say $tee "IN POSTSIM \@newgo " . dump( @newgo );
+  }
+  elsif ( ( $pierce eq "y" ) and ( $last ) )
+  {
+    @newgo = @bomb; say $tee "IN POSTSIM \@newgo " . dump( @newgo );
+  }
+
+
+  unless ( ( $pierce eq "y" ) and ( !$last ) )
+  {
+    @newgo = uniq( @newgo );
+    if ( $dowhat{dumpfiles} eq "y" )
     {
-      push( @newbowl, $dirfiles{reps}{$rid} );
-      #say $tee "IN POSTSIM EXISTS \$countblock $countblock \$dirfiles{reps}{\$rid} \$dirfiles{reps}{$rid} " . dump( $dirfiles{reps}{$rid} );# NOT $repfile
+      my $repline = $repfile;
+      $repline =~ s/\.csv?/-incharge\.csv/;
+      open( REPFILE, ">$repline" ) or die;
+      foreach my $line ( @newgo )
+      {
+        say REPFILE $line;
+      }
+      close REPFILE;
     }
   }
 
-  my $repline = $repfile;
-  $repline =~ s/\.csv?/-incharge\.csv?/;
-  open( REPFILE, ">$repline" ) or die;
-  foreach my line ( @newbowl )
-  {
-    say $line;
-  }
-  close REPFILE;
-
 
 
   my @selectbag;
-  if ( $dowhat{precomputed} eq "" )
-  { 
-    foreach my $line ( @newbowl )
-    {
-      my $lin;
-      if ( ( $line ne "" ) and ( $line ne " " ) and ( $line ne "\n" ) )
+
+  unless ( ( $pierce eq "y" ) and ( !$last ) )
+  {
+
+    if ( $dowhat{precomputed} eq "" )
+    { 
+      foreach my $line ( @newgo )
       {
-        chomp $line;
-        $line =~ s/\n/°/g;
-        $line =~ s/°/\n/g;
-        $line =~ s/[()%]//g;
-        $line =~ s/,?//;
-        $line =~ s/,?//;
-        $line =~ s/,?//;
-        $line =~ s/ ?//;
-        $line =~ s/ ?//;
-
-        my @elts = split(/,/, $line); 
-        my $touse = $elts[0];
-
-        $touse = Sim::OPT::clean( $touse, $mypath, $file );
-
-        if ( ( ( $dowhat{names} eq "short" ) or ( $dowhat{names} eq "medium" ) ) and ( $touse =~ /^\d+$/ ) )
+        my $lin;
+        if ( ( $line ne "" ) and ( $line ne " " ) and ( $line ne "\n" ) )
         {
-          my $clear = $inst_r->{$touse};
+          chomp $line;
+          $line =~ s/\n/°/g;
+          $line =~ s/°/\n/g;
+          $line =~ s/[()%]//g;
+          $line =~ s/,?//;
+          $line =~ s/,?//;
+          $line =~ s/,?//;
+          $line =~ s/ ?//;
+          $line =~ s/ ?//;
 
-          if ( ( !defined($clear) ) or ( $clear eq "" ) )
+          my @elts = split(/,/, $line); 
+          my $touse = $elts[0];
+
+          $touse = Sim::OPT::clean( $touse, $mypath, $file );
+
+          if ( ( ( $dowhat{names} eq "short" ) or ( $dowhat{names} eq "medium" ) ) and ( $touse =~ /^\d+$/ ) )
           {
-            my $k = "$mypath/$file" . "_" . $touse;
-            $clear = $inst_r->{$k};
-          }
+            my $clear = $inst_r->{$touse};
 
-
-          if ( ( !defined($clear) ) or ( $clear eq "" ) )
-          {
-            die "Cannot map crypto id '$touse' to clear instance (names=short)";
-          }
-          $touse = $clear;
-        }
-
-        my ( @elements, @names, @obtaineds, @newnames ); #say $tee "\@keepcolumns: " . dump( @keepcolumns );
-        foreach my $elm_ref (@keepcolumns)
-        {
-          my @cols = @{ $elm_ref };
-          my $name = $cols[0];
-          my $number = $cols[1];
-          push ( @elements, $elts[$number] ); #say $tee "\PUSH \$elts[\$number]: " . dump( $elts[$number] );
-          #say $tee "\$elts: $elts, \$number: $number";
-          push ( @names, $name );
-        } #say $tee "ELEMENTS: ". dump( @elements ); say $tee "NAMES: ". dump( @names );
-
-        if ( not ( scalar( @weighttransforms ) == 0 ) )
-        {
-          my $coun = 0;
-          foreach my $elt_ref ( @weighttransforms )
-          {
-            my @els = @{ $elt_ref };
-            my $newname = $els[0];
-            my $transform = $els[1];
-            my $obtained = eval ( $transform ); #say $tee "HERE \$transform: $transform, \$obtained: $obtained";
-            push ( @obtaineds, $obtained );
-            push ( @newnames, $newname );
-            $coun++;
-          }
-        }
-        else
-        {
-          @obtaineds = @elements;
-          @newnames = @names;
-        }
-        #say $tee "ELEMENTS: ". dump( @elements ); #say $tee "\@obtaineds: ". dump( @obtaineds );
-        #say $tee "NAMES: ". dump( @names ); #say $tee "NEWNAMES: ". dump( @newnames );
-
-        if ( !defined( $dirfiles{countnettotrowlength}  ) ) #THIS SWITCHES OFF AFTER THE FIRST PASS
-        {
-          $dirfiles{totrowlength} = ( scalar( @obtaineds ) * 2 );
-          $dirfiles{countnettotrowlength}++; #THIS CALCULATES THE LENGTH OF THE ROW AND STORES IT
-        }
-        
-        say $tee "IN SIM \$dowhat{discard} $dowhat{discard}";
-        unless ( $obtaineds[-1] eq $dowhat{discard} )
-        {
-          $lin =  "$touse,";
-
-          my $coun = 0; #say $tee "PRINTNG OBTAINEDS: " . dump ( @obtaineds ) ;
-          foreach my $elt ( @obtaineds )
-          {
-            $lin = $lin . "$newnames[$coun],";
-            unless ( $coun == $#obtaineds )
+            if ( ( !defined($clear) ) or ( $clear eq "" ) )
             {
-              $lin = $lin . "$elt,";
+              my $k = "$mypath/$file" . "_" . $touse;
+              $clear = $inst_r->{$k};
             }
-            else 
+
+
+            if ( ( !defined($clear) ) or ( $clear eq "" ) )
             {
-              $lin = $lin . "$elt";
+              die "Cannot map crypto id '$touse' to clear instance (names=short)";
             }
-            $coun++;
+            $touse = $clear;
+          }
+
+          my ( @elements, @names, @obtaineds, @newnames ); #say $tee "\@keepcolumns: " . dump( @keepcolumns );
+          foreach my $elm_ref (@keepcolumns)
+          {
+            my @cols = @{ $elm_ref };
+            my $name = $cols[0];
+            my $number = $cols[1];
+            push ( @elements, $elts[$number] ); #say $tee "\PUSH \$elts[\$number]: " . dump( $elts[$number] );
+            #say $tee "\$elts: $elts, \$number: $number";
+            push ( @names, $name );
+          } #say $tee "ELEMENTS: ". dump( @elements ); say $tee "NAMES: ". dump( @names );
+
+          if ( not ( scalar( @weighttransforms ) == 0 ) )
+          {
+            my $coun = 0;
+            foreach my $elt_ref ( @weighttransforms )
+            {
+              my @els = @{ $elt_ref };
+              my $newname = $els[0];
+              my $transform = $els[1];
+              my $obtained = eval ( $transform ); #say $tee "HERE \$transform: $transform, \$obtained: $obtained";
+              push ( @obtaineds, $obtained );
+              push ( @newnames, $newname );
+              $coun++;
+            }
+          }
+          else
+          {
+            @obtaineds = @elements;
+            @newnames = @names;
+          }
+          #say $tee "ELEMENTS: ". dump( @elements ); #say $tee "\@obtaineds: ". dump( @obtaineds );
+          #say $tee "NAMES: ". dump( @names ); #say $tee "NEWNAMES: ". dump( @newnames );
+
+          if ( !defined( $dirfiles{countnettotrowlength}  ) ) #THIS SWITCHES OFF AFTER THE FIRST PASS
+          {
+            $dirfiles{totrowlength} = ( scalar( @obtaineds ) * 2 );
+            $dirfiles{countnettotrowlength}++; #THIS CALCULATES THE LENGTH OF THE ROW AND STORES IT
+          }
+          
+          say $tee "IN SIM \$dowhat{discard} $dowhat{discard}";
+          unless ( $obtaineds[-1] eq $dowhat{discard} )
+          {
+            $lin =  "$touse,";
+
+            my $coun = 0; #say $tee "PRINTNG OBTAINEDS: " . dump ( @obtaineds ) ;
+            foreach my $elt ( @obtaineds )
+            {
+              $lin = $lin . "$newnames[$coun],";
+              unless ( $coun == $#obtaineds )
+              {
+                $lin = $lin . "$elt,";
+              }
+              else 
+              {
+                $lin = $lin . "$elt";
+              }
+              $coun++;
+            }
+            push( @selectbag, $lin );
           }
-          push( @selectbag, $lin );
         }
       }
     }
+    say $tee "IN POSTSIM \@selectbag " . dump( @selectbag );
   }
-  say $tee "IN POSTSIM \@selectbag " . dump( @selectbag );
   
 
-  
-
-
   my @weightbag;
-  if ( $dowhat{precomputed} eq "" )
+
+  unless ( ( $pierce eq "y" ) and ( !$last ) )
   {
-    my $counterline = 0;
-    my ( @containerone, @containernames, @containertitles, @containertwo, @containerthree, @maxes, @mins );
-    foreach my $line ( @selectbag) 
+    if ( $dowhat{precomputed} eq "" )
     {
-      chomp $line;
-      my @elts = split( ",", $line );
-      my $touse = shift( @elts ); # IT CHOPS AWAY THE FIRST ELEMENT DESTRUCTIVELY
-      my $countel = 0;
-      my $countcol = 0;
-      my $countcn = 0;
-      foreach my $elt ( @elts )
+      my $counterline = 0;
+      my ( @containerone, @containernames, @containertitles, @containertwo, @containerthree, @maxes, @mins );
+      foreach my $line ( @selectbag) 
       {
-        if ( Sim::OPT::Descend::odd( $countel ) )
+        chomp $line;
+        my @elts = split( ",", $line );
+        my $touse = shift( @elts ); # IT CHOPS AWAY THE FIRST ELEMENT DESTRUCTIVELY
+        my $countel = 0;
+        my $countcol = 0;
+        my $countcn = 0;
+        foreach my $elt ( @elts )
         {
-          push ( @{ $containerone[ $countcol ] }, $elt );
-          $countcol++;
+          if ( Sim::OPT::Descend::odd( $countel ) )
+          {
+            push ( @{ $containerone[ $countcol ] }, $elt );
+            $countcol++;
+          }
+          else
+          {
+            push ( @{ $containernames[$countcn] }, $elt );
+            $countcn++;
+          }
+          $countel++;
+        }
+        push ( @containertitles, $touse );
+      }
+
+
+      my $countcolm = 0;
+      foreach my $colref ( @containerone )
+      {
+        my @column = @{ $colref }; # DEREFERENCE
+      
+        if ( max( @column ) != 0) # FILLS THE UNTRACTABLE VALUES
+        {
+          push ( @maxes, max( @column ) );
         }
         else
         {
-          push ( @{ $containernames[$countcn] }, $elt );
-          $countcn++;
+          push ( @maxes, "NOTHING1" );
         }
-        $countel++;
-      }
-      push ( @containertitles, $touse );
-    }
-
-
-    my $countcolm = 0;
-    foreach my $colref ( @containerone )
-    {
-      my @column = @{ $colref }; # DEREFERENCE
-    
-      if ( max( @column ) != 0) # FILLS THE UNTRACTABLE VALUES
-      {
-        push ( @maxes, max( @column ) );
-      }
-      else
-      {
-        push ( @maxes, "NOTHING1" );
-      }
-    
-      push ( @mins, min( @column ) );
-    
-      foreach my $el ( @column )
-      {
-        my $eltrans;
-        if ( $maxes[ $countcolm ] != 0 )
+      
+        push ( @mins, min( @column ) );
+      
+        foreach my $el ( @column )
         {
-          $eltrans = ( $el / $maxes[$countcolm] ) ;
+          my $eltrans;
+          if ( $maxes[ $countcolm ] != 0 )
+          {
+            $eltrans = ( $el / $maxes[$countcolm] ) ;
+          }
+          else
+          {
+            $eltrans = "NOTHING2" ;
+          }
+          push ( @{ $containertwo[$countcolm] }, $eltrans) ; #print $tee "ELTRANS: $eltrans\n";
+        }
+        $countcolm++;
+      }
+      
+      my $countrow = 0;
+      foreach ( @selectbag )
+      {
+        my $growlin;
+        my ( @c1row, @c2row, @cnamesrow );
+
+        foreach my $c1_ref ( @containerone )
+        {
+          my @c1col = @{ $c1_ref };
+          push( @c1row, $c1col[ $countrow ] );
+        }
+
+        foreach my $cnames_ref ( @containernames )
+        {
+          my @cnamescol = @{ $cnames_ref };
+          push( @cnamesrow, $cnamescol[$countrow] );
+        }
+
+        foreach my $c2_ref ( @containertwo )
+        {
+          my @c2col = @{ $c2_ref };
+          push( @c2row, $c2col[$countrow] );
+        }
+
+
+        my ( $numberels, $scalar_keepcolumns );
+        if ( not ( scalar( @weighttransforms ) == 0 ) )
+        {
+          $numberels = scalar( @weighttransforms );
+          $scalar_keepcolumns = scalar( @weighttransforms );
         }
         else
         {
-          $eltrans = "NOTHING2" ;
+          $numberels = scalar( @keepcolumns );
+          $scalar_keepcolumns = scalar( @keepcolumns );
         }
-        push ( @{ $containertwo[$countcolm] }, $eltrans) ; #print $tee "ELTRANS: $eltrans\n";
+
+
+        my $wsum = 0; # WEIGHTED SUM
+        my $counterin = 0;
+        foreach my $elt ( @c2row )
+        {
+          my $newelt = ( $elt * abs( $weights[$counterin] ) );
+          $wsum = ( $wsum + $newelt ) ;
+          $counterin++;
+        }
+
+        $growlin = $growlin . "$containertitles[ $countrow ],";
+
+        $countel = 0;
+        foreach my $el ( @c1row )
+        {
+          $growlin = $growlin . "$cnamesrow[$countel],";
+          $growlin = $growlin . "$el,";
+
+          $countel++;
+        }
+
+        foreach my $el ( @c2row )
+        {
+          $growlin = $growlin . "$el,";
+        }
+
+        $growlin = $growlin . "$wsum";
+        push( @weightbag, $growlin );
+        $countrow++;
       }
-      $countcolm++;
-    }
-    
-    my $countrow = 0;
-    foreach ( @selectbag )
-    {
-      my $growlin;
-      my ( @c1row, @c2row, @cnamesrow );
-
-      foreach my $c1_ref ( @containerone )
-      {
-        my @c1col = @{ $c1_ref };
-        push( @c1row, $c1col[ $countrow ] );
-      }
-
-      foreach my $cnames_ref ( @containernames )
-      {
-        my @cnamescol = @{ $cnames_ref };
-        push( @cnamesrow, $cnamescol[$countrow] );
-      }
-
-      foreach my $c2_ref ( @containertwo )
-      {
-        my @c2col = @{ $c2_ref };
-        push( @c2row, $c2col[$countrow] );
-      }
-
-
-      my ( $numberels, $scalar_keepcolumns );
-      if ( not ( scalar( @weighttransforms ) == 0 ) )
-      {
-        $numberels = scalar( @weighttransforms );
-        $scalar_keepcolumns = scalar( @weighttransforms );
-      }
-      else
-      {
-        $numberels = scalar( @keepcolumns );
-        $scalar_keepcolumns = scalar( @keepcolumns );
-      }
-
-
-      my $wsum = 0; # WEIGHTED SUM
-      my $counterin = 0;
-      foreach my $elt ( @c2row )
-      {
-        my $newelt = ( $elt * abs( $weights[$counterin] ) );
-        $wsum = ( $wsum + $newelt ) ;
-        $counterin++;
-      }
-
-      $growlin = $growlin . "$containertitles[ $countrow ],";
-
-      $countel = 0;
-      foreach my $el ( @c1row )
-      {
-        $growlin = $growlin . "$cnamesrow[$countel],";
-        $growlin = $growlin . "$el,";
-
-        $countel++;
-      }
-
-      foreach my $el ( @c2row )
-      {
-        $growlin = $growlin . "$el,";
-      }
-
-      $growlin = $growlin . "$wsum";
-      push( @weightbag, $growlin );
-      $countrow++;
-    }
-  }  #say $tee "IN POSTSIM \@weightbag " . dump( @weightbag );
+    }  say $tee "IN POSTSIM \@weightbag " . dump( @weightbag );
+  }
   
-
-  
-
   @weightbag = uniq( @weightbag ); 
-  return( \@weightbag, \%dirfiles, $csim );
+  if ( not ( $pierce eq "y" ) )
+  {
+    return( \@weightbag, \%dirfiles, $csim );
+  }
+  else 
+  {
+    return( \@weightbag, \%dirfiles, $csim, $instant, \@bomb );
+  }
 
   close TOFILE;
   close OUTFILE;
@@ -955,6 +1015,6 @@ Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is proprietary. The open-source, GPL version of it can be found at https://metacpan.org/dist/Sim-OPT.
+Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This software is distributed under a dual licence, open-source (GPL v3) and proprietary. The present copy is GPL. By consequence, this is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
 =cut
